Method: LHS::Interceptors::ExtendedRollbar::Handler.init

Defined in:
lib/lhs/interceptors/extended_rollbar/handler.rb

.initObject



8
9
10
11
12
13
14
# File 'lib/lhs/interceptors/extended_rollbar/handler.rb', line 8

def self.init
  proc do |options|
    # as handlers cant influence what actually is reported to rollbar
    # this just makes sure that Rollbar is already loaded when this class is loaded,
    # so that we can extend rollbar loging
  end
end